#!/bin/bash
#   DESCRIPTION
#     Example script to coordinate rman backup of oracle database.
#     This is run by the pre_snap.sh before the Quorum backup process.
#     
#     Please note that this script is crafted for our test environment
#     (one DB instance and retain only one backup) and user will need
#     to use ORACLE DBA skills to update this script based on real world
#     Oracle backup needs and requirements.

function run_rman
{
    \rm -f $1
    cat > $1
    rman @$1
}

# Modify the settings as your need of oracle installations and configurations

ORACLE_BASE=/opt/oracle
ORACLE_HOME=$ORACLE_BASE/product/11.2.0/db_1

#
# details for databases to be backed up
# 
BACKUP_BASE=/backup01
BACKUP_AREA=${BACKUP_BASE}/rdbms/physical/orcl
BACKUP_LOG_DIR=~/oracle_backup


# Make backup
mkdir -p ~/${BACKUP_LOG_DIR}
chmod 777 ~/${BACKUP_LOG_DIR}
db=orcl

    #
    # Backup the database
    #
    run_rman ${BACKUP_LOG_DIR}/ora_backup_${db}.rman <<EOF
        set echo on;
        connect target sys/Quorum1@orcl;
        run {
            configure backup optimization on;
            configure controlfile autobackup on;
            allocate channel ${db} 
                type disk format '${BACKUP_AREA}/%U';
            set controlfile autobackup 
                format for device type disk to '${BACKUP_AREA}/cf_%F';
            backup incremental level 0 
                 as compressed backupset 
                 database plus archivelog 
                 delete all input;
            delete force noprompt obsolete;
            release channel ${db};
        }
        exit;
EOF
    rc=$?
    if test ! $rc -eq 0; then
        echo RMAN backup of ${db} failed
        exit $rc
    fi

exit 0
